% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hyperg.R
\name{hyperg}
\alias{hyperg}
\title{Compute hypergeometric backbone probabilities}
\usage{
hyperg(B)
}
\arguments{
\item{B}{graph: Bipartite graph object of class matrix, sparse matrix, igraph, edgelist, or network object.}
}
\value{
backbone, a list(positive, negative, summary). Here
    `positive` is a matrix of probabilities of edge weights being equal to or above the observed value in the projection,
    `negative` is a matrix of probabilities of edge weights being equal to or below the observed value in the projection, and
    `summary` is a data frame summary of the inputted matrix and the model used including: model name, number of rows, skew of row sums, number of columns, skew of column sums, and running time.
}
\description{
`hyperg` computes the probability of observing
    a higher or lower edge weight using the hypergeometric distribution.
    Once computed, use \code{\link{backbone.extract}} to return
    the backbone matrix for a given alpha value.
}
\details{
Specifically, this function compares an edge's observed weight in the projection \eqn{B*t(B)} to the
    distribution of weights expected in a projection obtained from a random bipartite graph where
    the row vertex degrees are fixed but the column vertex degrees are allowed to vary.

The "backbone" S3 class object returned is composed of two matrices, a summary dataframe and (optionally, if generated by using \link{fdsm}) a 'dyad_values' vector.
}
\examples{
hyperg_probs <- hyperg(davis)
}
\references{
\href{http://dx.doi.org/10.1371/journal.pone.0017994}{Tumminello, Michele and Miccichè, Salvatore and Lillo, Fabrizio and Piilo, Jyrki and Mantegna, Rosario N. 2011. "Statistically Validated Networks in Bipartite Complex Systems." PLOS ONE, 6(3), DOI:10.1371/journal.pone.0017994.}

\href{https://doi.org/10.1007/s13278-013-0107-y}{Neal, Zachary. 2013. “Identifying Statistically Significant Edges in One-Mode Projections.” Social Network Analysis and Mining 3 (4). Springer: 915–24. DOI:10.1007/s13278-013-0107-y.}
}
